@@ -22,7 +22,7 @@
 #ifndef NODE_CONFIG_H
 #define NODE_CONFIG_H
 
-#define NODE_CFLAGS "-O2 -pipe -rdynamic -D_GNU_SOURCE -DHAVE_CONFIG_H=1 -pthread -g -DHAVE_OPENSSL=1 -DX_STACKSIZE=65536 -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -DHAVE_FDATASYNC=0 -DPLATFORM=\"openbsd\" -D__POSIX__=1 -Wno-unused-parameter -D_FORTIFY_SOURCE=2 -I/usr/local/include/node"
+#define NODE_CFLAGS "-O2 -pipe -rdynamic -pthread -m32 -g -DHAVE_OPENSSL=1 -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -DHAVE_FDATASYNC=0 -DARCH=\"ia32\" -DPLATFORM=\"openbsd\" -D__POSIX__=1 -Wno-unused-parameter -D_FORTIFY_SOURCE=2 -I/usr/local/include/node"
 #define NODE_PREFIX "/usr/local"
 
 #endif /* NODE_CONFIG_H */
